@@ -551,7 +551,7 @@ void Core::emitRichNotification(const QString &evid, const QString &title, const
                          nullptr, KNotification::CloseOnTimeout, QStringLiteral("powerdevil"));
 }
 
-bool Core::emitBatteryChargePercentNotification(int currentPercent, int previousPercent, const QString &udi)
+bool Core::emitBatteryChargePercentNotification(int currentPercent, int previousPercent, const QString &udi, Core::ChargeNotificationFlags flags)
 {
     using namespace Solid;
     Device device(udi);
@@ -620,7 +620,11 @@ bool Core::emitBatteryChargePercentNotification(int currentPercent, int previous
         return false;
     }
 
-    if (m_backend->acAdapterState() == BackendInterface::Plugged) {
+    // Make sure a notificaton that's kept open updates its percentage live.
+    updateBatteryNotifications(currentPercent);
+
+    if (m_backend->acAdapterState() == BackendInterface::Plugged
+            && !flags.testFlag(ChargeNotificationFlag::NotifyWhenAcPluggedIn)) {
         return false;
     }
 
@@ -644,7 +648,7 @@ void Core::handleLowBattery(int percent)
 
     m_lowBatteryNotification = new KNotification(QStringLiteral("lowbattery"), KNotification::Persistent, nullptr);
     m_lowBatteryNotification->setComponentName(QStringLiteral("powerdevil"));
-    m_lowBatteryNotification->setTitle(i18n("Battery Low (%1% Remaining)", percent));
+    updateBatteryNotifications(percent); // sets title
     m_lowBatteryNotification->setText(i18n("Battery running low - to continue using your computer, plug it in or shut it down and change the battery."));
     m_lowBatteryNotification->setUrgency(KNotification::CriticalUrgency);
     m_lowBatteryNotification->sendEvent();
@@ -659,7 +663,7 @@ void Core::handleCriticalBattery(int percent)
     // no parent, but it won't leak, since it will be closed both in case of timeout or direct action
     m_criticalBatteryNotification = new KNotification(QStringLiteral("criticalbattery"), KNotification::Persistent, nullptr);
     m_criticalBatteryNotification->setComponentName(QStringLiteral("powerdevil"));
-    m_criticalBatteryNotification->setTitle(i18n("Battery Critical (%1% Remaining)", percent));
+    updateBatteryNotifications(percent); // sets title
 
     const QStringList actions = {i18nc("Cancel timeout that will automatically put system to sleep because of low battery", "Cancel")};
 
@@ -693,6 +697,17 @@ void Core::handleCriticalBattery(int percent)
     m_criticalBatteryNotification->sendEvent();
 }
 
+void Core::updateBatteryNotifications(int percent)
+{
+    if (m_lowBatteryNotification) {
+        m_lowBatteryNotification->setTitle(i18n("Battery Low (%1% Remaining)", percent));
+    }
+
+    if (m_criticalBatteryNotification) {
+        m_criticalBatteryNotification->setTitle(i18n("Battery Critical (%1% Remaining)", percent));
+    }
+}
+
 void Core::onAcAdapterStateChanged(PowerDevil::BackendInterface::AcAdapterState state)
 {
     qCDebug(POWERDEVIL);
@@ -743,7 +758,8 @@ void Core::onBatteryChargePercentChanged(int percent, const QString &udi)
     m_batteriesPercent[udi] = percent;
 
     if (currentPercent < previousPercent) {
-        if (emitBatteryChargePercentNotification(currentPercent, previousPercent, udi)) {
+        // When battery drains while still plugged in, warn nevertheless.
+        if (emitBatteryChargePercentNotification(currentPercent, previousPercent, udi, ChargeNotificationFlag::NotifyWhenAcPluggedIn)) {
             // Only refresh status if a notification has actually been emitted
             loadProfile();
         }
